@@ -74,12 +74,12 @@ static void on_realize (GtkWidget *widget, gpointer user_data)
 
 #ifdef GDK_WINDOWING_WAYLAND
     if (GDK_IS_WAYLAND_WINDOW (window)) {
-        window_handle = gdk_wayland_window_get_wl_surface (window);
+        window_handle = (guintptr) gdk_wayland_window_get_wl_surface (window);
     } else
 #endif
 #ifdef GDK_WINDOWING_X11
     if (GDK_IS_X11_WINDOW (window)) {
-        window_handle = GDK_WINDOW_XID (window);
+        window_handle = (guintptr) GDK_WINDOW_XID (window);
     } else
 #endif
     {
@@ -126,6 +126,8 @@ static gboolean on_draw (GtkWidget *widget, cairo_t *cr, gpointer user_data)
 
         cairo_paint (cr);
     }
+
+    return TRUE;
 }
 
 static gboolean on_key_released (GtkWidget *widget,
@@ -149,8 +151,6 @@ static gboolean on_key_released (GtkWidget *widget,
 int main (int argc, char *argv[])
 {
     RygelPlaybinRenderer *renderer;
-    GError *error = NULL;
-    GMainLoop *loop;
     MainData data;
     GdkCursor *cursor;
 
@@ -164,7 +164,6 @@ int main (int argc, char *argv[])
 
     data.window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
     data.video = gtk_drawing_area_new ();
-    gtk_widget_set_double_buffered (data.video, FALSE);
     gtk_container_add (GTK_CONTAINER (data.window), data.video);
     g_signal_connect (data.video, "realize", G_CALLBACK (on_realize), &data);
     gtk_widget_add_events (data.video,
